@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.30 2002/10/07 08:09:15 bazsi Exp $ */
+ * $Id: io.c,v 1.31 2002/10/14 08:05:38 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -843,14 +843,11 @@ static int inet_address2sockaddr_in(struct address_info *c, int sasize, struct s
 		memcpy(sa, &a->sa, sizeof(a->sa));
 		return 1;
 	}
-	if (tcp_addr(in,
-		     a ? a->ip->length : 7, 
-		     a ? (char *) a->ip->data : "0.0.0.0",
-		     a->port))
+	if (!tcp_addr(in,
+		     a && a->ip ? a->ip->length : 7, 
+		     a && a->ip ? (char *) a->ip->data : "0.0.0.0",
+		     a ? a->port : 0))
 		return 0;
-	else
-		if (!a->ip && !tcp_addr(in, 0, NULL, a->port))
-			return 0;
 	return 1;
 }
 
